========
Codebots
========

.. image:: https://github.com/franaudo/codebots/actions/workflows/docs.yml/badge.svg
        :target: https://github.com/franaudo/codebots/actions/workflows/docs.yml
        :alt: Documentation Status

.. image:: https://github.com/franaudo/codebots/actions/workflows/python-package.yml/badge.svg
        :target: https://github.com/franaudo/codebots/actions/workflows/python-package.yml
        :alt: Python package

.. image:: https://github.com/franaudo/codebots/actions/workflows/codeql-analysis.yml/badge.svg
        :target: https://github.com/franaudo/codebots/actions/workflows/codeql-analysis.yml
        :alt: CodeQL


This is a collection of simple bots to help with boring tasks during coding.

Currently supported bots:

* EmailBot: useful to get an email when a task is complete
* SlackBot: same thing, but you get a slack message instead.
* TeleBot: again the same thing, but you get a message on Telegram this time.
* sshBot: this is different...it will help you with ssh stuff.
* DeployBot: this bot is in charge of helping you with repository deployments.

Full documentation: https://franaudo.github.io/codebots/latest/.


Features
--------

* Free software: MIT license
* Easy to use
* Awesome command line interface
* Fun (well, for someone...)

Credits
~~~~~~~

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
